@@ -480,7 +480,14 @@ HardwareTransformerInlineFormset = inlineformset_factory(DataTransformer, Hardwa
 HardwareStatsTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareStatsDataTransformer, extra=1,exclude =['updated_at','created_at'])
 
 
-class DataTransformerForm(BaseForm):
+class DataTransformerForm(forms.ModelForm):
+    def __init__(self, *args, **kwargs):
+        super(DataTransformerForm, self).__init__(*args, **kwargs)
+
+        for name in self.fields.keys():
+            self.fields[name].widget.attrs.update({
+                'class': 'form-control',
+            })
 
     def add_fields(self, form, index):
         super(DataTransformerForm, self).add_fields(form, index)
