@@ -249,6 +249,10 @@ class Accessory(models.Model):
         self.updated_at = timezone.now()
         return super().save(*args, **kwargs)
 
+    @property
+    def has_data_transformer(self):
+        return hasattr(self, 'datatransformer') or hasattr(self, 'data_transformer')
+
     class Meta:
         indexes = [
             models.Index(fields=['id']),
