@@ -2,7 +2,7 @@ from rest_framework import serializers
 
 from data.models.models import CalibrationConstants, Calibration, Channel, Accessory, HardwareConfig, PiPico, \
     DHT22, MCP3008, ModProbe, VEML7700, Hardware, Hub, SPIIo, SerialIo, PwmIo, I2cIo, DeviceFileIo, MCPAnalogIo, \
-    PiPicoAnalogIo,PiPicoACAnalogIo, PiGpio
+    PiPicoAnalogIo, PiPicoACAnalogIo, PiGpio, DataTransformer
 
 
 class CalibrationConstantsSerializer(serializers.ModelSerializer):
@@ -29,7 +29,7 @@ class CalibrationSerializer(serializers.ModelSerializer):
 class ChannelSerializer(serializers.ModelSerializer):
     class Meta:
         model = Channel
-        fields = ['id', 'type', 'channel_index','hardware']
+        fields = ['id', 'type', 'channel_index', 'hardware']
 
 
 class AccessorySerializer(serializers.ModelSerializer):
@@ -39,7 +39,16 @@ class AccessorySerializer(serializers.ModelSerializer):
     class Meta:
         model = Accessory
         fields = ['id', 'category', 'type', 'display_name', 'aid',
-                  'calibration','channels']
+                  'calibration', 'channels']
+
+
+class DataTransformerSerializer(serializers.ModelSerializer):
+    # channels = ChannelSerializer(source='channel_set', many=True)
+    calibration = CalibrationSerializer(source='calibration_set', many=True, read_only=False)
+
+    class Meta:
+        model = DataTransformer
+        fields = '__all__'
 
 
 class HardwareConfigSerializer(serializers.HyperlinkedModelSerializer):
@@ -80,7 +89,6 @@ class VEML7700Serializer(serializers.ModelSerializer):
 
 class HardwareSerializer(serializers.ModelSerializer):
 
-
     def to_json_array(self, obt_list):
         serialized_hardware = []
         for obj in obt_list:
@@ -108,7 +116,6 @@ class HardwareSerializer(serializers.ModelSerializer):
         fields = '__all__'
 
 
-
 class SPIIoSerializer(serializers.ModelSerializer):
     class Meta:
         model = SPIIo
@@ -120,41 +127,49 @@ class SerialIoSerializer(serializers.ModelSerializer):
         model = SerialIo
         fields = '__all__'
 
+
 class PwmIoSerializer(serializers.ModelSerializer):
     class Meta:
         model = PwmIo
         fields = '__all__'
 
+
 class I2cIoSerializer(serializers.ModelSerializer):
     class Meta:
         model = I2cIo
         fields = '__all__'
 
+
 class DeviceFileIoSerializer(serializers.ModelSerializer):
     class Meta:
         model = DeviceFileIo
         fields = '__all__'
 
+
 class MCPAnalogIoSerializer(serializers.ModelSerializer):
     class Meta:
         model = MCPAnalogIo
         fields = '__all__'
 
+
 class PiPicoAnalogIoSerializer(serializers.ModelSerializer):
     class Meta:
         model = PiPicoAnalogIo
         fields = '__all__'
 
+
 class PiPicoACAnalogIoSerializer(serializers.ModelSerializer):
     class Meta:
         model = PiPicoACAnalogIo
         fields = '__all__'
 
+
 class PiGpioSerializer(serializers.ModelSerializer):
     class Meta:
         model = PiGpio
         fields = '__all__'
 
+
 class HardwareIOSerializer(serializers.ModelSerializer):
 
     def to_json_array(self, obt_list):
@@ -187,7 +202,6 @@ class HardwareIOSerializer(serializers.ModelSerializer):
         elif isinstance(obj, PiGpio):
             return PiGpioSerializer(obj, context=self.context).to_representation(obj)
 
-
         return super(HardwareIOSerializer, self).to_representation(obj)
 
     class Meta:
