@@ -385,7 +385,7 @@ class AccessoryViewSet(viewsets.ModelViewSet):
         accessory_form = AccessoryForm(instance=accessory)
         calibration_form = CalibrationForm(initial={'accessory': accessory})
 
-        if accessory.hasattr('datatransformer'):
+        if accessory.has_data_transformer:
             data_transformer = accessory.datatransformer
             formset = DataTransformerForm(instance=data_transformer)
         else:
